@@ -9,9 +9,15 @@
     https://tools.ietf.org/html/rfc6750
 """
 
-# flake8: noqa
-
-from .errors import *
+from .errors import InvalidRequestError, InvalidTokenError, InsufficientScopeError
 from .parameters import add_bearer_token
 from .wrappers import BearerToken
 from .validator import BearerTokenValidator
+
+
+__all__ = [
+    'InvalidRequestError', 'InvalidTokenError', 'InsufficientScopeError',
+    'add_bearer_token',
+    'BearerToken',
+    'BearerTokenValidator',
+]
